---
title: processing
---

## Common functions for gentropy dataset processing (data business logic)

:::gentropy.common.processing.parse_efos
:::gentropy.common.processing.extract_chromosome
:::gentropy.common.processing.extract_position
:::gentropy.common.processing.normalize_chromosome
:::gentropy.common.processing.maf
:::gentropy.common.processing.mac

## Harmonisation

:::gentropy.common.processing.harmonise_summary_stats
:::gentropy.common.processing.prepare_va
